==> muon-1.1.65.tar.bz2: muon-1.1.65/installer/ApplicationDetailsView/ApplicationDetailsView.cpp <==
/***************************************************************************
 *   Copyright © 2010 Jonathan Thomas <echidnaman@kubuntu.org>             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#include "ApplicationDetailsView.h"

// Qt includes
#include <QtGui/QVBoxLayout>

// KDE includes
#include <KIcon>

// Own includes
#include "ApplicationDetailsWidget.h"
#include "../Application.h"
#include "../BreadcrumbWidget/BreadcrumbItem.h"

ApplicationDetailsView::ApplicationDetailsView(QWidget *parent, ApplicationBackend *backend)
    : AbstractViewBase(parent)
{
    m_detailsWidget = new ApplicationDetailsWidget(this, backend);

    m_layout->addWidget(m_detailsWidget);

    m_crumb->setAssociatedView(this);

    connect(m_detailsWidget, SIGNAL(installButtonClicked(Application *)),
            this, SIGNAL(installButtonClicked(Application *)));
    connect(m_detailsWidget, SIGNAL(installButtonClicked(Application *, const QHash<QApt::Package *, QApt::Package::State> &)),
            this, SIGNAL(installButtonClicked(Application *, const QHash<QApt::Package *, QApt::Package::State> &)));
    connect(m_detailsWidget, SIGNAL(removeButtonClicked(Application *)),
            this, SIGNAL(removeButtonClicked(Application *)));
    connect(m_detailsWidget, SIGNAL(cancelButtonClicked(Application *)),
            this, SIGNAL(cancelButtonClicked(Application *)));
}

ApplicationDetailsView::~ApplicationDetailsView()
{
}

void ApplicationDetailsView::setApplication(Application *app)
{
    m_detailsWidget->setApplication(app);

    m_crumb->setText(app->name());
    m_crumb->setIcon(KIcon(app->icon()));
}

#include "ApplicationDetailsView.moc"

==> muon-1.3.0.tar.bz2: muon-1.3.0/installer/ApplicationDetailsView/ApplicationDetailsView.cpp <==
/***************************************************************************
 *   Copyright © 2010 Jonathan Thomas <echidnaman@kubuntu.org>             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#include "ApplicationDetailsView.h"

// Qt includes
#include <QtGui/QVBoxLayout>

// KDE includes
#include <KIcon>

// Own includes
#include "ApplicationDetailsWidget.h"
#include "../Application.h"
#include "../BreadcrumbWidget/BreadcrumbItem.h"

ApplicationDetailsView::ApplicationDetailsView(QWidget *parent, ApplicationBackend *backend)
    : AbstractViewBase(parent)
{
    m_detailsWidget = new ApplicationDetailsWidget(this, backend);

    m_layout->addWidget(m_detailsWidget);

    m_crumb->setAssociatedView(this);

    connect(m_detailsWidget, SIGNAL(installButtonClicked(Application*)),
            this, SIGNAL(installButtonClicked(Application*)));
    connect(m_detailsWidget, SIGNAL(installButtonClicked(Application*,QHash<QApt::Package*,QApt::Package::State>)),
            this, SIGNAL(installButtonClicked(Application*,QHash<QApt::Package*,QApt::Package::State>)));
    connect(m_detailsWidget, SIGNAL(removeButtonClicked(Application*)),
            this, SIGNAL(removeButtonClicked(Application*)));
    connect(m_detailsWidget, SIGNAL(cancelButtonClicked(Application*)),
            this, SIGNAL(cancelButtonClicked(Application*)));
}

ApplicationDetailsView::~ApplicationDetailsView()
{
}

void ApplicationDetailsView::setApplication(Application *app)
{
    m_detailsWidget->setApplication(app);

    m_crumb->setText(app->name());
    m_crumb->setIcon(KIcon(app->icon()));
}

#include "ApplicationDetailsView.moc"
